; ##############################################################################
; ##############################################################################
; ##############################################################################
; ADMUX  	ADC Multiplexer Selection Register										
; REFS1:0: 	Reference Selection Bits												
; REFS1 REFS0 	Voltage Reference Selection											
;  0	0 		AREF, Internal Vref turned off										
;  0 	1 		AVCC with external capacitor at AREF pin							
;  1 	0 		Internal 1.1V Voltage Reference with external capacitor at AREF pin	
;  1 	1 		Internal 2.56V Voltage Reference with external capacitor at AREF pin
; ADLAR: 		ADC Left Adjust Result												
; MUX4:0: 	Analog Channel and Gain Selection Bits									
;  00000 	ADC0																	
;  00001 	ADC1																	
;  00010 	ADC2																	
;  00011 	ADC3																	
;  00100 	ADC4																	
;  00101 	ADC5																	
;  00110 	ADC6																	
;  00111 	ADC7																	
;  11110 	1.1V (VBG)																
;  11111 	 0 V (GND)																
;																					
; ADCSRA  ADC Control and Status Register A										
; ADEN: ADC Enable																	
; ADSC: ADC Start Conversion														
; ADATE: ADC Auto Trigger Enable													
; ADIF: ADC Interrupt Flag															
; ADIE: ADC Interrupt Enable														
; ADPS2:0: ADC Prescaler Select Bits												
; ADPS2 ADPS1 	ADPS0 Division Factor												
;  0 	0 		0 		  2															
;  0 	0 		1 		  2															
;  0 	1 		0 		  4															
;  0 	1 		1 		  8															
;  1 	0 		0 		 16															
;  1 	0 		1 		 32															
;  1 	1 		0 		 64															
; *1 	1 		1 		128 (bei 20MHz)												
;																					
; ADCSRB  ADC Control and Status Register B										
; ACME: Analog Comparator Multiplexer Enable										
; ADTS2 ADTS1 ADTS0 	Trigger Source												
; *0 	0 		0 		Free Running mode											
;  0 	0 		1 		Analog Comparator											
;  0 	1 		0 		External Interrupt Request 0								
;  0 	1 		1 		Timer/Counter0 Compare Match								
;  1 	0 		0 		Timer/Counter0 Overflow										
;  1 	0 		1 		Timer/Counter1 Compare Match B								
;  1 	1 		0 		Timer/Counter1 Overflow										
;  1 	1 		1 		Timer/Counter1 Capture Event								
ADC_INITIALISIERUNG:
	; REFERENZ  										
;	ldi temp,((0<<REFS1)|(0<<REFS0)) ; ext REF			
	ldi temp,((0<<REFS1)|(1<<REFS0)) ; AVCC + KAPAZITT	
;	ldi temp,((1<<REFS1)|(1<<REFS0)) ; 2,56V			
;	ldi temp,((1<<REFS1)|(0<<REFS0)) ; 1,1V				
	STS ADMUX, temp
	; "FREE Running" + Vorteiler (zw. 50kHz...200kHz)	
	ldi temp,((1<<ADEN)|(1<<ADSC)|(1<<ADATE)|(1<<ADIF)|(0<<ADIE)|(1<<ADPS2)|(1<<ADPS1)|(1<<ADPS0)) 
	STS ADCSRA,temp       

	ldi temp,((0<<ACME)|(0<<ADTS2)|(0<<ADTS1)|(0<<ADTS0)) 
	STS ADCSRB,temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; MESSEN-ADC0																	
ADC_MESSEN_0:
	LDS temp,ADMUX
	andi temp,0b11100000	; ADC0	
;	ori  temp,0b00011110	;  11110 	1.1V (VBG)
;	ori  temp,0b00011111	;  11111 	 0 V (GND)
	STS ADMUX,temp
	rcall ADC_MESSUNG_TEMP1_TEMP2
	STS(adr_ADC_0_L),temp1
	STS(adr_ADC_0_H),temp2
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; MESSEN-ADC1																	
ADC_MESSEN_1:
	LDS temp,ADMUX
	andi temp, 0b11100000
	subi temp, -1			; ADC1
	STS ADMUX,temp
	rcall ADC_MESSUNG_TEMP1_TEMP2
	STS(adr_ADC_1_L),temp1
	STS(adr_ADC_1_H),temp2
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; MESSEN-ADC2																	
ADC_MESSEN_2:
	LDS temp,ADMUX
	andi temp, 0b11100000
	subi temp, -2			; ADC2
	STS ADMUX,temp
	rcall ADC_MESSUNG_TEMP1_TEMP2
	STS(adr_ADC_2_L),temp1
	STS(adr_ADC_2_H),temp2
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; MESSEN-ADC3																	
ADC_MESSEN_3:
	LDS temp,ADMUX
	andi temp, 0b11100000
	subi temp, -3			; ADC3
	STS ADMUX,temp
	rcall ADC_MESSUNG_TEMP1_TEMP2
	STS(adr_ADC_3_L),temp1
	STS(adr_ADC_3_H),temp2
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; MESSEN-ADC4																	
ADC_MESSEN_4:
	LDS temp,ADMUX
	andi temp, 0b11100000
	subi temp, -4			; ADC4
	STS ADMUX,temp
	rcall ADC_MESSUNG_TEMP1_TEMP2
	STS(adr_ADC_4_L),temp1
	STS(adr_ADC_4_H),temp2
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; MESSEN-ADC5																	
ADC_MESSEN_5:
	LDS temp,ADMUX
	andi temp, 0b11100000
	subi temp, -5			; ADC5
	STS ADMUX,temp
	rcall ADC_MESSUNG_TEMP1_TEMP2
	STS(adr_ADC_5_L),temp1
	STS(adr_ADC_5_H),temp2
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; MESSEN-ADC6																	
ADC_MESSEN_6:
	LDS temp,ADMUX
	andi temp, 0b11100000
	subi temp, -6			; ADC6
	STS ADMUX,temp
	rcall ADC_MESSUNG_TEMP1_TEMP2
	STS(adr_ADC_6_L),temp1
	STS(adr_ADC_6_H),temp2
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; MESSEN-ADC1																	
ADC_MESSEN_7:
	LDS temp,ADMUX
	andi temp, 0b11100000
	subi temp, -7			; ADC7
	STS ADMUX,temp
	rcall ADC_MESSUNG_TEMP1_TEMP2
	STS(adr_ADC_7_L),temp1
	STS(adr_ADC_7_H),temp2
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; VERSION: 25.01.2015															
; OUT: temp1+temp2																
ADC_MESSUNG_TEMP1_TEMP2:
;-------------------------------------------------------------------
; PAUSE (bei KANAL-UMSCHALTUNG)										
	call wait_1ms
;-------------------------------------------------------------------
	; INITIALISIERUUNG		
	clr temp1
	clr temp2
	; SCHLEIFE 				
	ldi temp9,8
;-------------------------------------------------------------------
; ADC-MESSUNG, warten bis ADIF-FLAG gesetzt							
ADC_MESSUNG_TEMP1_TEMP2_s1:
	LDS temp,ADCSRA		; auslesen	
	sbrs temp, ADIF		; skip if...
	rjmp ADC_MESSUNG_TEMP1_TEMP2_s1
;-------------------------------------------------------------------
; ADC-START (ADIF-FLAG lschen durch logisch "1")					
	STS ADCSRA,temp
;-------------------------------------------------------------------
; ADC-MESSUNG, warten bis ADIF-FLAG gesetzt							
ADC_MESSUNG_TEMP1_TEMP2_s2:
	LDS temp,ADCSRA		; auslesen	
	sbrs temp, ADIF		; skip if...
	rjmp ADC_MESSUNG_TEMP1_TEMP2_s2
;-------------------------------------------------------------------
; ERGEBNIS auslesen													
	LDS R0,ADCL		; zuerst das LOW-Byte	
	LDS R1,ADCH		; dann das HIGH BYTE	
	add temp1,R0	; addieren				
	adc temp2,R1
	dec temp9		; SCHLEIFE				
	brne ADC_MESSUNG_TEMP1_TEMP2_s1
;-------------------------------------------------------------------
; Runden, halben Divisor dazuaddieren								
	subi temp1,LOW (-4)
	sbci temp2,HIGH(-4)
;-------------------------------------------------------------------
; 	Ergebnis teilen													
	LSR temp2	; :2
	ROR temp1
	LSR temp2	; :2
	ROR temp1
	LSR temp2	; :2
	ROR temp1
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
ADC_WARTUNG:
	; ZEILE 1	
	call ASCII_CURSOR_ZEILE_1
	call ANZEIGE_ZEIT_KURZ				; ZEIT		
	; ZEILE 2	
	call ASCII_CURSOR_ZEILE_2
	call ANZEIGE_DATUM_KURZ				; ZEIT		
	
	; ZEILE 8
	call ASCII_CURSOR_ZEILE_8
	LDS temp1,(adr_ADC_0_L)
	LDS temp2,(adr_ADC_0_H)
	call ANZEIGE_5_STELLEN_TEMP1_TEMP2
	LDS temp1,(adr_ADC_1_L)
	LDS temp2,(adr_ADC_1_H)
	call ANZEIGE_5_STELLEN_TEMP1_TEMP2
	LDS temp1,(adr_ADC_2_L)
	LDS temp2,(adr_ADC_2_H)
	call ANZEIGE_5_STELLEN_TEMP1_TEMP2
	LDS temp1,(adr_ADC_3_L)
	LDS temp2,(adr_ADC_3_H)
	call ANZEIGE_5_STELLEN_TEMP1_TEMP2
	; ZEILE 9
	call ASCII_CURSOR_ZEILE_9
	LDS temp1,(adr_ADC_4_L)
	LDS temp2,(adr_ADC_4_H)
	call ANZEIGE_5_STELLEN_TEMP1_TEMP2
	LDS temp1,(adr_ADC_5_L)
	LDS temp2,(adr_ADC_5_H)
	call ANZEIGE_5_STELLEN_TEMP1_TEMP2
	LDS temp1,(adr_ADC_6_L)
	LDS temp2,(adr_ADC_6_H)
	call ANZEIGE_5_STELLEN_TEMP1_TEMP2
	LDS temp1,(adr_ADC_7_L)
	LDS temp2,(adr_ADC_7_H)
	call ANZEIGE_5_STELLEN_TEMP1_TEMP2
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
