; ##############################################################################
; ##############################################################################
; ##############################################################################
; WDTCSR  Watchdog Timer Control Register										
; WDIF WDIE WDP3 WDCE WDE WDP2 WDP1 WDP0										
; WDP3 WDP2 WDP1 WDP0 Time														
;	0 	0 	0 	0 	2K 	(2048) 	cycles 16 ms									
;	0 	0 	0 	1 	4K 	(4096) 	cycles 32 ms									
;	0 	0 	1 	0 	8K 	(8192) 	cycles 64 ms									
;	0 	0 	1 	1 	16K (16384) cycles 0.125 s									
;	0 	1 	0 	0 	32K (32768) cycles 0.25 s									
; 	0 	1 	0 	1 	64K (65536) cycles 0.5 s									
; *	0 	1 	1 	0 	128K (131072)cycles 1.0 s									
;	0 	1 	1 	1 	256K (262144)cycles 2.0 s									
;	1 	0 	0 	0 	512K (524288)cycles 4.0 s									
;	1 	0 	0 	1 	1024K(1048576)cycles 8.0 s									
; Wenn WDIE=1 dann wird zuerst die WDR-ISR aufgerufen 							
; und dann das System neu gestartet												
WDR_INITIALISIERUNG:
	WDR
	LDS TEMP, WDTCSR
	ori TEMP, (1<<WDCE) | (1<<WDE)
	STS WDTCSR, TEMP
	ldi temp, (1<<WDE)| (1<<WDIE)|(0<<WDP3)|(1<<WDP2)|(1<<WDP1)|(0<<WDP0)
	STS WDTCSR, TEMP
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; MCUSR  MCU Status Register													
; 7,6,5,JTRF,WDRF,BORF,EXTRF,PORF												
; NEUSTART ber WDR, wenn BORF,EXTRF,PORF gestzt ist							
NEUSTART_MIT_WDR:
	in temp, MCUSR
	andi temp,0b00000111
	tst temp
	brne NEUSTART_MIT_WDR_FEHLER
	ret
NEUSTART_MIT_WDR_FEHLER:
	out MCUSR,NULL
	rjmp NEUSTART_MIT_WDR_FEHLER
; ##############################################################################
; ##############################################################################
; ##############################################################################
; Diese Routine wird bei WDR-Zeitberschreitung aufgerufen, hier knnte man		
; sich z.B. den Fehler anzeigen lasen, oder DATEN in den EEPROM schreiben		
WDT:
	WDR
	sbi (LED_GRUEN_PORT),LED_GRUEN_PIN_NR		; GRN aus	
	cbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB an	
	cbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  an	
	call wait_100ms
	sbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB aus	
	sbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  aus	
	call wait_100ms
	rjmp WDT
reti
; ##############################################################################
; ##############################################################################
; ##############################################################################
SRAM_CLEAR:
	ldi ZL, LOW (SRAM_START)
	ldi ZH, HIGH(SRAM_START)
	ldi temp,0
SRAM_CLEAR_w:
	ST z+,temp
	cpi ZH, HIGH(RAMEND-2)	; Vergleich?		
	brlo SRAM_CLEAR_w		; kleiner => SPRUNG	
	cpi ZL, LOW(RAMEND-2)	; Vergleich?		
	brlo SRAM_CLEAR_w		; kleiner => SPRUNG	
	breq SRAM_CLEAR_w		; gleich  => SPRUNG	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
PROGRAMM_CHECK:
	; NULL		
	tst NULL
	brne PROGRAMM_CHECK_FEHLER_SCHWER
	; EINS		
	mov temp,EINS
	cpi temp,1
	brne PROGRAMM_CHECK_FEHLER_SCHWER
	; SRAM CHECK
	LDS temp,(adr_SRAM_CHECK)
	cpi temp,'S'
	brne PROGRAMM_CHECK_FEHLER_SCHWER
	; FARBE		
	LDS temp,(adr_GRAFIC_FARBE)
	andi temp,0b11110000
	tst temp
	brne PROGRAMM_CHECK_ERROR
	ret
;-------------------------------------------------------------------------------
PROGRAMM_CHECK_ERROR:
	STS(adr_ERROR_WERT),temp
	ldi temp,(ERROR_FARBE)
	STS(adr_ERROR_CODE),temp
ret
;-------------------------------------------------------------------------------
PROGRAMM_CHECK_FEHLER_SCHWER:
	CLI											; INTERRUPTS sperren	
	sbi (LED_GRUEN_PORT),(LED_GRUEN_PIN_NR)		; GRN aus	
	sbi (LED_GELB_PORT),(LED_GELB_PIN_NR)		; GELB aus  
	call wait_100ms
	cbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  an	
	call wait_100ms
	sbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  aus	
	rjmp PROGRAMM_CHECK_FEHLER_SCHWER
; ##############################################################################
; ##############################################################################
; ##############################################################################
LED_INITIALISIERUNG:
	; auf AUSGANG								
	sbi (LED_GRUEN_DDR),(LED_GRUEN_PIN_NR)			; GRN		
	sbi (LED_GELB_DDR),(LED_GELB_PIN_NR)			; GELB		
	sbi (LED_ROT_DDR),(LED_ROT_PIN_NR)				; ROT		
	sbi (BEEP_DDR),(BEEP_PIN_NR)					; BEEP		
	sbi (RELAIS_KLICK_DDR),(RELAIS_KLICK_PIN_NR)	; RELAIS-KLICK
	sbi (RELAIS_POWER_DDR),(RELAIS_POWER_PIN_NR)	; RELAIS-POWER
	sbi (TESTA_DDR),(TESTA_PIN_NR)					; TEST-PIN	
	sbi (TESTB_DDR),(TESTB_PIN_NR)					; TEST-PIN	
	; LED an									
	cbi (LED_GRUEN_PORT),(LED_GRUEN_PIN_NR)			; GRN an   	
	cbi (LED_GELB_PORT),(LED_GELB_PIN_NR)			; GELB an		
	cbi (LED_ROT_PORT),(LED_ROT_PIN_NR)				; ROT  an		

	sbi (BEEP_PORT),(BEEP_PIN_NR)					; BEEP-aus		

	sbi (RELAIS_KLICK_PORT),(RELAIS_KLICK_PIN_NR)	; RELAIS-KLICK-aus		
	sbi (RELAIS_POWER_PORT),(RELAIS_POWER_PIN_NR)	; RELAIS-POWER-aus		

	cbi (TESTA_PORT),(TESTA_PIN_NR)					; TEST-A-PIN-LOW		
	sbi (TESTA_PORT),(TESTA_PIN_NR)					; TEST-A-PIN-HIGH		

	cbi (TESTB_PORT),(TESTB_PIN_NR)					; TEST-B-PIN-LOW		
	sbi (TESTB_PORT),(TESTB_PIN_NR)					; TEST-B-PIN-HIGH		


ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
LED_TEST:
	sbi (LED_GRUEN_PORT),(LED_GRUEN_PIN_NR)			; GRN aus	
	sbi (LED_GELB_PORT),(LED_GELB_PIN_NR)			; GELB aus	
	sbi (LED_ROT_PORT),(LED_ROT_PIN_NR)				; ROT  aus	

	cbi (RELAIS_KLICK_PORT),(RELAIS_KLICK_PIN_NR)	; RELAIS-KLICK-an		
	call wait_100ms
	cbi (LED_GRUEN_PORT),(LED_GRUEN_PIN_NR)			; GRN an   
	call wait_100ms
	cbi (LED_GELB_PORT),(LED_GELB_PIN_NR)			; GELB an	
	call wait_100ms
	cbi (LED_ROT_PORT),(LED_ROT_PIN_NR)				; ROT  an	
	call wait_100ms

	sbi (LED_GRUEN_PORT),(LED_GRUEN_PIN_NR)			; GRN aus	
	sbi (LED_GELB_PORT),(LED_GELB_PIN_NR)			; GELB aus	
	sbi (LED_ROT_PORT),(LED_ROT_PIN_NR)				; ROT  aus	
	sbi (RELAIS_KLICK_PORT),(RELAIS_KLICK_PIN_NR)	; RELAIS-KLICK-aus		
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
BETRIEBSSTUNDEN:
	LDS temp1,(adr_ss)
	LDS temp2,(adr_BS_ss_OLD)
	cp temp1,temp2
	brne BETRIEBSSTUNDEN_ss
	ret
BETRIEBSSTUNDEN_ss:
	STS(adr_BS_ss_OLD),temp1
	; ss				
	LDS temp,(adr_BS_ss)
	inc temp
	STS(adr_BS_ss),temp
	cpi temp,60
	brsh BETRIEBSSTUNDEN_mm
	ret
BETRIEBSSTUNDEN_mm:
	STS(adr_BS_ss),NULL
	; mm				
	LDS temp,(adr_BS_mm)
	inc temp
	STS(adr_BS_mm),temp
	cpi temp,60
	brsh BETRIEBSSTUNDEN_hh
	ret
BETRIEBSSTUNDEN_hh:
	STS(adr_BS_mm),NULL
	; mm				
	LDS temp,(adr_BS_hh)
	inc temp
	STS(adr_BS_hh),temp
	cpi temp,24
	brsh BETRIEBSSTUNDEN_TAG
	ret
BETRIEBSSTUNDEN_TAG:
	STS(adr_BS_hh),NULL
	; mm				
	LDS temp1,(adr_BS_TAG_L)
	LDS temp2,(adr_BS_TAG_H)
	add temp1,EINS
	adc temp2,NULL
	STS(adr_BS_TAG_L),temp1
	STS(adr_BS_TAG_H),temp2
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
BERECHNUNG_SONNENAUFGANG_SONNENUNTERGANG:
	LDS temp,(adr_ss)
	cpi temp,5
	breq BERECHNUNG_SONNENAUFGANG_SONNENUNTERGANG_w
	ret
BERECHNUNG_SONNENAUFGANG_SONNENUNTERGANG_w:
	LDS temp1,(adr_TAG)
	LDS temp, (adr_MESZ)
	add temp1,temp
	LDS temp2,(adr_TAG_OLD)
	cp temp1,temp2
	brne BERECHNUNG_SONNENAUFGANG_SONNENUNTERGANG_RUN
	ret
;-------------------------------------------------------------------------------
BERECHNUNG_SONNENAUFGANG_SONNENUNTERGANG_RUN:
	STS(adr_TAG_OLD),temp1
	; TAG				
	LDS temp1,(adr_TAG)
	dec temp1		; TAG-1		
	cpi temp1,31	
	brsh BERECHNUNG_SONNENAUFGANG_SONNENUNTERGANG_ERROR
	; MONAT 			
	LDS temp2,(adr_MONAT)
	dec temp2		; MONAT-1	
	cpi temp2,12
	brsh BERECHNUNG_SONNENAUFGANG_SONNENUNTERGANG_ERROR
	rjmp BERECHNUNG_SONNENAUFGANG_SONNENUNTERGANG_ACTION
;-------------------------------------------------------------------------------
BERECHNUNG_SONNENAUFGANG_SONNENUNTERGANG_ERROR:
	STS(adr_SONNE_AUFGANG_mm)  ,EINS
	STS(adr_SONNE_AUFGANG_hh)  ,EINS
	STS(adr_SONNE_UNTERGANG_mm),EINS
	STS(adr_SONNE_UNTERGANG_hh),EINS
ret
;-------------------------------------------------------------------------------
BERECHNUNG_SONNENAUFGANG_SONNENUNTERGANG_ACTION:
	; MESZ				
	LDS temp3,(adr_MESZ)
	andi temp3,0b00000001
	; MONAT				
	ldi temp,31	
	MUL temp2,temp	; x31		
	; TAG				
	add R0,temp1	; addieren	
	adc R1,NULL
	LSL R0			; x2		
	ROL R1
	; Z auf Tabelle					
	LDI ZL,low (TABELLE_SONNENAUFGANG*2)
	LDI ZH,high(TABELLE_SONNENAUFGANG*2)
	add ZL,R0
	adc ZH,R1
	; WERT aus Tabelle laden		
	LPM temp1, Z+  	; LOW -BYTE
	LPM temp2, Z  	; HIGH-BYTE
	rcall BERECHNUNG_SONNENAUFGANG_SONNENUNTERGANG_UMWANDLUNG_TEMP1_TEMP2
	STS(adr_SONNE_AUFGANG_mm) ,temp1
	add temp2,temp3	; MESZ		
	STS(adr_SONNE_AUFGANG_hh) ,temp2
	; Z auf Tabelle					
	LDI ZL,low (TABELLE_SONNENUNTERGANG*2)
	LDI ZH,high(TABELLE_SONNENUNTERGANG*2)
	add ZL,R0
	adc ZH,R1
	; WERT aus Tabelle laden		
	LPM temp1, Z+  	; LOW -BYTE
	LPM temp2, Z  	; HIGH-BYTE
	rcall BERECHNUNG_SONNENAUFGANG_SONNENUNTERGANG_UMWANDLUNG_TEMP1_TEMP2
	STS(adr_SONNE_UNTERGANG_mm),temp1
	add temp2,temp3	; MESZ		
	STS(adr_SONNE_UNTERGANG_hh),temp2

	call EEPROM_KONFIGURATION_SPEICHERN
ret
;-------------------------------------------------------------------------------
BERECHNUNG_SONNENAUFGANG_SONNENUNTERGANG_UMWANDLUNG_TEMP1_TEMP2:
	ldi temp5,255
BERECHNUNG_SONNENAUFGANG_SONNENUNTERGANG_UMWANDLUNG_TEMP1_TEMP2_s:
	; 100 subtrahieren			
	subi temp1, LOW (100)
	sbci temp2, HIGH(100)
	; Anzahl Schleifen Zhlen	
	inc temp5
	; ist noch positiv ?		
	tst temp2
	brpl BERECHNUNG_SONNENAUFGANG_SONNENUNTERGANG_UMWANDLUNG_TEMP1_TEMP2_s
	; 100 addieren				
	subi temp1, LOW (-100)
	sbci temp2, HIGH(-100)
	; Schleifenwert				
	mov temp2,temp5
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
BERECHNUNG_NACHTMODUS_ON_OFF:
	; ss=1 ?				
	LDS temp,(adr_ss)
	cpi temp,1
	breq BERECHNUNG_NACHTMODUS_ON_OFF_w1
	ret
;-------------------------------------------------------------------------------
BERECHNUNG_NACHTMODUS_ON_OFF_w1:
	; aktuelle ZEIT			
	LDS R0,(adr_hh)
	LDS R1,(adr_mm)
	; NACHTMODUS ON ?	
	LDS temp1,(adr_NACHTMODUS_ON_hh)
	LDS temp2,(adr_NACHTMODUS_ON_mm)
	cp R0,temp1	; hh 
	brne BERECHNUNG_NACHTMODUS_ON_OFF_w2
	cp R1,temp2	; mm 
	brne BERECHNUNG_NACHTMODUS_ON_OFF_w2
	; NACHTMODUS ON		
	rjmp NACHTMODUS_ON
;-------------------------------------------------------------------------------
BERECHNUNG_NACHTMODUS_ON_OFF_w2:
	; NACHTMODUS OFF ?	
	LDS temp1,(adr_NACHTMODUS_OFF_hh)
	LDS temp2,(adr_NACHTMODUS_OFF_mm)
	cp R0,temp1	; hh 
	brne BERECHNUNG_NACHTMODUS_ON_OFF_FERTIG
	cp R1,temp2	; mm 
	brne BERECHNUNG_NACHTMODUS_ON_OFF_FERTIG
	; NACHTMODUS OFF	
	rjmp NACHTMODUS_OFF
;-------------------------------------------------------------------------------
BERECHNUNG_NACHTMODUS_ON_OFF_FERTIG:
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
NACHTMODUS_ON:
	STS(adr_NACHTMODUS_ON),EINS
	; FARBE						
	LDS temp,(adr_FARBE_NACHT)
	STS(adr_FARBE_AKTUELL),temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
NACHTMODUS_OFF:
	STS(adr_NACHTMODUS_ON),NULL
	; FARBE						
	LDS temp,(adr_FARBE_TAG)
	STS(adr_FARBE_AKTUELL),temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
BERECHNUNG_DISPLAY_ON_OFF:
	; ss=2 ?				
	LDS temp,(adr_ss)
	cpi temp,2
	breq BERECHNUNG_DISPLAY_ON_OFF_w1
	ret
;-------------------------------------------------------------------------------
BERECHNUNG_DISPLAY_ON_OFF_w1:
	; aktuelle ZEIT			
	LDS R0,(adr_hh)
	LDS R1,(adr_mm)
	; DISPLAY ON ?			
	LDS temp1,(adr_DISPLAY_ON_hh)
	LDS temp2,(adr_DISPLAY_ON_mm)
	cp R0,temp1		; hh 
	brne BERECHNUNG_DISPLAY_ON_OFF_w2
	cp R1,temp2		; hh 
	brne BERECHNUNG_DISPLAY_ON_OFF_w2
	; DISPLAY ON 			
	rjmp DISPLAY_ON
;-------------------------------------------------------------------------------
BERECHNUNG_DISPLAY_ON_OFF_w2:
	; DISPLAY OFF ?			
	LDS temp1,(adr_DISPLAY_OFF_hh)
	LDS temp2,(adr_DISPLAY_OFF_mm)
	cp R0,temp1		; hh 
	brne BERECHNUNG_DISPLAY_ON_OFF_FERTIG
	cp R1,temp2		; hh 
	brne BERECHNUNG_DISPLAY_ON_OFF_FERTIG
	; DISPLAY OFF 			
	rjmp DISPLAY_OFF
;-------------------------------------------------------------------------------
BERECHNUNG_DISPLAY_ON_OFF_FERTIG:
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; DISPLAY + LED ein																
DISPLAY_ON:
	sbi (RELAIS_POWER_PORT),(RELAIS_POWER_PIN_NR)	; RELAIS-POWER-aus		
	; STATUS abfragen	
	LDS temp,(TCCR1B)
	tst temp
	breq DISPLAY_ON_RUN
	ret
;-------------------------------------------------------------------------------
DISPLAY_ON_RUN:
	; LED auf AUSGANG		
	sbi (LED_GRUEN_DDR),(LED_GRUEN_PIN_NR)			; GRN		
	sbi (LED_GELB_DDR),(LED_GELB_PIN_NR)			; GELB		
	sbi (LED_ROT_DDR),(LED_ROT_PIN_NR)				; ROT		
	; GRAFIC			
	call GRAFIC_CLEAR
	call TOUCH_CLEAR
	call VGA_TEST_FARBBALKEN
	call VGA_ON
	call WAIT_1s
	call WAIT_1s
	
	ldi temp,255
	STS(adr_TOUCH_RUECKGABEWERT),temp

	call MODUS_1_MENUE_0						; ANALOGUHR	
	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; DISPLAY + LED ausschalten														
DISPLAY_OFF:
	; LED auf EINGANG		
	cbi (LED_GRUEN_DDR),(LED_GRUEN_PIN_NR)			; GRN		
	cbi (LED_GELB_DDR),(LED_GELB_PIN_NR)			; GELB		
	cbi (LED_ROT_DDR),(LED_ROT_PIN_NR)				; ROT		
	; GRAFIC				
	call GRAFIC_CLEAR
	call FARBE_GELB
	call ASCII_CURSOR_ZEILE_6	
	call ANZEIGE_TEXT_WAIT_KURZ
	call WAIT_1s
	call VGA_OFF
	call WAIT_1s
	cbi (RELAIS_POWER_PORT),(RELAIS_POWER_PIN_NR)	; RELAIS-POWER-an		
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
STUNDEN_KLICK_KURZ:
	cbi (RELAIS_KLICK_PORT),(RELAIS_KLICK_PIN_NR)	; RELAIS-KLICK-an		
	call WAIT_100ms
	sbi (RELAIS_KLICK_PORT),(RELAIS_KLICK_PIN_NR)	; RELAIS-KLICK-aus		
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
STUNDEN_KLICK:
	; NACHTMODUS ?	
	LDS temp,(adr_NACHTMODUS_ON)
	tst temp
	breq STUNDEN_KLICK_w1
	sbi (RELAIS_KLICK_PORT),(RELAIS_KLICK_PIN_NR)	; RELAIS-KLICK-aus		
	ret
;-------------------------------------------------------------------------------
STUNDEN_KLICK_w1:
	; ss NULL ?		
	LDS temp,(adr_ss)
	tst temp
	breq STUNDEN_KLICK_w2
	sbi (RELAIS_KLICK_PORT),(RELAIS_KLICK_PIN_NR)	; RELAIS-KLICK-aus		
	ret
;-------------------------------------------------------------------------------
STUNDEN_KLICK_w2:
	; mm NULL ?		
	LDS temp,(adr_mm)
	tst temp
	breq STUNDEN_KLICK_w3
	ret
;-------------------------------------------------------------------------------
STUNDEN_KLICK_w3:
	cbi (RELAIS_KLICK_PORT),(RELAIS_KLICK_PIN_NR)	; RELAIS-KLICK-an		
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
BEEP_TOUCH:
	LDS temp,(adr_TOUCH_BEEP_ON)
	tst temp
	brne BEEP_TOUCH_RUN
	ret
BEEP_TOUCH_RUN:
	cbi (BEEP_PORT),(BEEP_PIN_NR)					; BEEP-an	
BEEP_TOUCH_s:
	call wait_1ms	
	dec temp
	brne BEEP_TOUCH_s
	sbi (BEEP_PORT),(BEEP_PIN_NR)					; BEEP-aus	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
BEEP_KURZ:
	cbi (BEEP_PORT),(BEEP_PIN_NR)					; BEEP-an	
	call wait_20ms	
	sbi (BEEP_PORT),(BEEP_PIN_NR)					; BEEP-aus	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
BEEP_2x_KURZ:
	cbi (BEEP_PORT),(BEEP_PIN_NR)					; BEEP-an	
	call wait_1ms	
	sbi (BEEP_PORT),(BEEP_PIN_NR)					; BEEP-aus	
	call wait_100ms
	cbi (BEEP_PORT),(BEEP_PIN_NR)					; BEEP-an	
	call wait_1ms	
	sbi (BEEP_PORT),(BEEP_PIN_NR)					; BEEP-aus	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
BEEP_LANG:
	cbi (BEEP_PORT),(BEEP_PIN_NR)					; BEEP-an	
	call wait_500ms	
	sbi (BEEP_PORT),(BEEP_PIN_NR)					; BEEP-aus	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
STOP_PROGRAMM:
	WDR
rjmp STOP_PROGRAMM
; ##############################################################################
; ##############################################################################
; ##############################################################################
; FEHLER_CODE=temp1																
; FEHLER_WERT=temp2																
; AUFBAU:																		
; 8 BYTE pro DATENSATZ															
; <CODE><WERT><TAG><MONAT><JAHR><hh><mm><ss>									
FEHLERSPEICHER_WRITE_TEMP1_TEMP2:
	; sichern		
	push temp
	push temp9
	push YL
	push YH
	push ZL
	push ZH
	; SCHLEIFE		
	ldi ZL, LOW(adr_FEHLER_SPEICHER80+64)
	ldi ZH,HIGH(adr_FEHLER_SPEICHER80+64)
	ldi YL, LOW(adr_FEHLER_SPEICHER80+72)
	ldi YH,HIGH(adr_FEHLER_SPEICHER80+72)
	ldi temp9,9
;-------------------------------------------------------------------------------
FEHLERSPEICHER_WRITE_TEMP1_TEMP2_s:
	LD temp,Z+	; 1
	ST Y+,temp
	LD temp,Z+	; 2
	ST Y+,temp
	LD temp,Z+	; 3
	ST Y+,temp
	LD temp,Z+	; 4
	ST Y+,temp
	LD temp,Z+	; 5
	ST Y+,temp
	LD temp,Z+	; 6
	ST Y+,temp
	LD temp,Z+	; 7
	ST Y+,temp
	LD temp,Z+	; 8
	ST Y+,temp
	SBIW ZL,16	; -16
	SBIW YL,16	; -16
	dec temp9
	brne FEHLERSPEICHER_WRITE_TEMP1_TEMP2_s
;-------------------------------------------------------------------------------
	ldi ZL, LOW(adr_FEHLER_SPEICHER80)
	ldi ZH,HIGH(adr_FEHLER_SPEICHER80)
	ST Z+,temp1			; CODE	
	ST Z+,temp2			; WERT	
	LDS temp,(adr_TAG)	; TAG	
	ST Z+,temp
	LDS temp,(adr_MONAT); MONAT	
	ST Z+,temp
	LDS temp,(adr_JAHR)	; JAHR	
	ST Z+,temp
	LDS temp,(adr_hh)	; hh	
	ST Z+,temp
	LDS temp,(adr_mm)	; mm	
	ST Z+,temp
	LDS temp,(adr_ss)	; ss	
	ST Z+,temp
	; wieder herstellen	
	pop ZH
	pop ZL
	pop YH
	pop YL
	pop temp9
	pop temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
